@@ -2,6 +2,7 @@
  *   Copyright 2007      Francesco Rossi <redsh@email.it>                  *
  *   Copyright 2006-2007 Mick Kappenburg <ksudoku@kappendburg.net>         *
  *   Copyright 2006-2007 Johannes Bergmeier <johannes.bergmeier@gmx.net>   *
+ *   Copyright 2015      Ian Wadham <iandw.au@gmail.com>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,6 +28,7 @@
 #include <QtDebug>
 
 #include "sudokuboard.h"
+#include "mathdokugenerator.h"
 
 namespace ksudoku {
 
@@ -69,38 +71,53 @@ bool Puzzle::init(int difficulty, int symmetry) {
 	SudokuBoard * board = new SudokuBoard (m_graph);
 
 	// Generate a puzzle and its solution.
-	board->generatePuzzle (m_puzzle, m_solution,
+	bool success =  board->generatePuzzle (m_puzzle, m_solution,
 			      (Difficulty) difficulty, (Symmetry) symmetry);
-	board->getMoveList (m_hintList);
+	if (success) {
+	    board->getMoveList (m_hintList);
+	}
+	// Too many tries at generating a puzzle that meets the user's reqs.
+	else {
+	    m_puzzle.clear();		// Wipe the puzzle and its solution.
+	    m_solution.clear();
+	}
 	delete board;
-	return true;
+	return success;
 }
 
 int Puzzle::init(const BoardContents & values) {
 	if(m_initialized) return -1;
+	int result = -1;
+	SudokuType t = m_graph->specificType();
 
-	SudokuBoard * board = new SudokuBoard (m_graph);
-
-	// Save the puzzle values and SudokuBoard's solution (if any).
+	// Save the puzzle values and solution (if any).
 	m_puzzle = values;
-	m_solution = board->solveBoard (m_puzzle);
+	m_hintList.clear();
 
-	// Get SudokuBoard to check the solution.
-	int result = board->checkPuzzle (m_puzzle);
-	if (result >= 0) {
-	    result = 1;		// There is one solution.
-	}
-	else if (result == -1) {
-	    result = 0;		// There is no solution.
+	if ((t != Mathdoku) && (t != KillerSudoku)) {
+	    SudokuBoard * board = new SudokuBoard (m_graph);
+	    m_solution = board->solveBoard (m_puzzle);
+
+	    // Get SudokuBoard to check the solution.
+	    result = board->checkPuzzle (m_puzzle);
+	    if (result != 0) {
+		board->getMoveList (m_hintList);
+	    }
+	    if (result >= 0) {
+		result = 1;		// There is one solution.
+	    }
+	    else if (result == -1) {
+		result = 0;		// There is no solution.
+	    }
+	    else {
+		result = 2;		// There is more than one solution.
+	    }
+	    delete board;
 	}
 	else {
-	    result = 2;		// There is more than one solution.
+	    MathdokuGenerator mg (m_graph);
+	    result = mg.solveMathdokuTypes (m_solution, &m_hintList);
 	}
-	m_hintList.clear();
-	if (result != 0) {
-	    board->getMoveList (m_hintList);
-	}
-	delete board;
 	return result;
 }
 
